==> devextreme-21.2.1-alpha-21243-0310.tgz: package/cjs/renovation/ui/scroll_view/common/base_scrollable_props.js <==
/**
 * DevExtreme (cjs/renovation/ui/scroll_view/common/base_scrollable_props.js)
 * Version: 21.2.0 (build 21243-0310)
 * Build date: Tue Aug 31 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.BaseScrollableProps = void 0;
var _support = require("../../../../core/utils/support");
var _get_default_option_value = require("../utils/get_default_option_value");
var _themes = require("../../../../ui/themes");
var _message = _interopRequireDefault(require("../../../../localization/message"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
var BaseScrollableProps = Object.defineProperties({
    addWidgetClass: false,
    disabled: false,
    visible: true,
    rtlEnabled: false,
    classes: "",
    direction: "vertical",
    pullDownEnabled: false,
    reachBottomEnabled: false,
    forceGeneratePockets: false,
    needScrollViewContentWrapper: false,
    needScrollViewLoadPanel: false,
    needRenderScrollbars: true
}, {
    aria: {
        get: function() {
            return {}
        },
        configurable: true,
        enumerable: true
    },
    useNative: {
        get: function() {
            return (0, _get_default_option_value.getDefaultUseNative)()
        },
        configurable: true,
        enumerable: true
    },
    bounceEnabled: {
        get: function() {
            return (0, _get_default_option_value.getDefaultBounceEnabled)()
        },
        configurable: true,
        enumerable: true
    },
    scrollByContent: {
        get: function() {
            return (0, _get_default_option_value.isDesktop)() ? _support.touch : true
        },
        configurable: true,
        enumerable: true
    },
    pullingDownText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-pullingDownText")
        },
        configurable: true,
        enumerable: true
    },
    pulledDownText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-pulledDownText")
        },
        configurable: true,
        enumerable: true
    },
    refreshingText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-refreshingText")
        },
        configurable: true,
        enumerable: true
    },
    reachBottomText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-reachBottomText")
        },
        configurable: true,
        enumerable: true
    }
});
exports.BaseScrollableProps = BaseScrollableProps;

==> devextreme-22.1.1-alpha-21335-0845.tgz: package/cjs/renovation/ui/scroll_view/common/base_scrollable_props.js <==
/**
 * DevExtreme (cjs/renovation/ui/scroll_view/common/base_scrollable_props.js)
 * Version: 22.1.0 (build 21335-0845)
 * Build date: Wed Dec 01 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.BaseScrollableProps = void 0;
var _support = require("../../../../core/utils/support");
var _get_default_option_value = require("../utils/get_default_option_value");
var _themes = require("../../../../ui/themes");
var _message = _interopRequireDefault(require("../../../../localization/message"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
var BaseScrollableProps = Object.defineProperties({
    addWidgetClass: false,
    disabled: false,
    visible: true,
    classes: "",
    direction: "vertical",
    pullDownEnabled: false,
    reachBottomEnabled: false,
    forceGeneratePockets: false,
    needScrollViewContentWrapper: false,
    needScrollViewLoadPanel: false,
    needRenderScrollbars: true,
    refreshStrategy: "simulated"
}, {
    aria: {
        get: function() {
            return {}
        },
        configurable: true,
        enumerable: true
    },
    bounceEnabled: {
        get: function() {
            return (0, _get_default_option_value.getDefaultBounceEnabled)()
        },
        configurable: true,
        enumerable: true
    },
    scrollByContent: {
        get: function() {
            return (0, _get_default_option_value.isDesktop)() ? _support.touch : true
        },
        configurable: true,
        enumerable: true
    },
    pullingDownText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-pullingDownText")
        },
        configurable: true,
        enumerable: true
    },
    pulledDownText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-pulledDownText")
        },
        configurable: true,
        enumerable: true
    },
    refreshingText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-refreshingText")
        },
        configurable: true,
        enumerable: true
    },
    reachBottomText: {
        get: function() {
            return (0, _themes.isMaterial)((0, _themes.current)()) ? "" : _message.default.format("dxScrollView-reachBottomText")
        },
        configurable: true,
        enumerable: true
    }
});
exports.BaseScrollableProps = BaseScrollableProps;
